@@ -1,28 +1,17 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarconfiguresettingsdialog.h"
 #include "gravatarconfiguresettingswidget.h"
 #include "misc/gravatarcache.h"
-#include "PimCommon/ConfigureImmutableWidgetUtils"
+#include <PimCommon/ConfigureImmutableWidgetUtils>
 
 #include <KLocalizedString>
+#include <KPluralHandlingSpinBox>
+#include <KSeparator>
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -35,8 +24,13 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Configure Gravatar"));
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    auto *topLayout = new QVBoxLayout(this);
     topLayout->setObjectName(QStringLiteral("toplayout"));
+
+    mGravatarConfigureSettings = new GravatarConfigureSettingsWidget(this);
+    mGravatarConfigureSettings->setObjectName(QStringLiteral("gravatarconfiguresettings"));
+    topLayout->addWidget(mGravatarConfigureSettings);
+
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -46,9 +40,6 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &GravatarConfigureSettingsDialog::slotRestoreDefault);
     okButton->setDefault(true);
 
-    mGravatarConfigureSettings = new GravatarConfigureSettingsWidget(this);
-    mGravatarConfigureSettings->setObjectName(QStringLiteral("gravatarconfiguresettings"));
-    topLayout->addWidget(mGravatarConfigureSettings);
     topLayout->addWidget(buttonBox);
     load();
 }
